@@ -4,7 +4,7 @@ from Amisynth.utils import json_storage
 @xfox.addfunc(xfox.funcs)
 async def jsonArray(*claves, **kwargs):
     if not claves:
-        raise ValueError("Error: Debes proporcionar al menos una clave en $jsonArray[]")
+        raise ValueError("❌ La función `$jsonArray` devolvió un error: Se esperaba un valor válido en la posición 1, pero se obtuvo un valor vacío.")
     
     data = json_storage
     
@@ -20,4 +20,4 @@ async def jsonArray(*claves, **kwargs):
         
         return ""
     except Exception as e:
-        raise ValueError(f"Error al insertar array en JSON: {e}")
+        raise ValueError(f"❌ La función `$jsonArray` devolvió un error: {e}")
