@@ -4,7 +4,7 @@ from Amisynth.utils import menu_options
 import xfox
 
 @xfox.addfunc(xfox.funcs)
-async def getMenuID(*args, **kwargs):
+async def getSelectMenuID(*args, **kwargs):
     """Agrega una opción al menú de selección, almacenándola en una lista por ID."""
     if "ctx_interaction_env" in kwargs:
         interaction = kwargs["ctx_interaction_env"]
